| Title: | BioPathNet: Three Pod Analysis System |
|---|---|
| Description: | This package aims to provide a simple interface to perform the Three Pod Analysis of RNASeq dataaset. In addition, this also provides utility functions to perform the individual components. |
| Authors: | Ali Sajid Imami [aut, cre] (ORCID: <https://orcid.org/0000-0003-3684-3539>), Khaled Alganem [aut] (ORCID: <https://orcid.org/0000-0003-3234-7669>), Xiaolu Zhang [aut] (ORCID: <https://orcid.org/0000-0001-5595-7270>), Marissa Ann Smail [aut] (ORCID: <https://orcid.org/0000-0002-9743-3771>) |
| Maintainer: | Ali Sajid Imami <[email protected]> |
| License: | GPL-3 |
| Version: | 0.2.0 |
| Built: | 2026-06-02 09:58:08 UTC |
| Source: | https://github.com/CogDisResLab/BioPathNet |
Construct a BPNList object
BPNList(input, gsea, enrichr, ilincs, leading, revigo, integrated)BPNList(input, gsea, enrichr, ilincs, leading, revigo, integrated)
input |
tbl_df A tibble with the differentially expressed genes |
gsea |
GSEAResult An object containing the GSEA results |
enrichr |
EnrichRResult An object containing the EnrichR results |
ilincs |
iLINCSResult An object containing the iLINCS results |
leading |
LEResult An object containing the Leading Edge Analysis results |
revigo |
RevigoResult An object containing the Revigo results |
integrated |
IntegratedResult An object containing the Integrated results |
A BPNList object
TRUETRUE
This class takes care of the entire analysis infrastructure of the BioPathNet analysis. This class is created with inputting a list of differentially expressed genes and then stores the subsequently generated results.
An object of class BPNList
inputtbl_df. A tibble with Two columns of gene names and logfc values and optionally a p-value column
gseaGSEAResult. An instance of GSEAResult-class class storing the results GSEA Analysis
enrichrEnrichRResult. An instance of EnrichRResult-class class storing the results EnrichR Analysis
ilincsiLINCSResult. An instance of iLINCSResult-class class storing the results iLINCS Analysis
leadingLEResult. An instance of LEResult-class class storing the results Leading Edge Analysis
revigoRevigoResult. An instance of RevigoResult-class class storing the results Revigo Analysis
integratedIntegratedResult. An instance of IntegratedResult-class class storing the results after integrating the three components
TRUETRUE
This function takes in a BPNList object and returns a BPNList object with the enrichr slot updated with process EnrichR Results
do_enrichr_pod(bpn, alpha = 0.05, lower = NULL, upper = NULL, useFDR = TRUE)do_enrichr_pod(bpn, alpha = 0.05, lower = NULL, upper = NULL, useFDR = TRUE)
bpn |
BPNList An object of class BPNList created from prepare_data |
alpha |
numeric The Alpha value for statistical significance. Defaults to 0.05. |
lower |
numeric The cutoff for down-regulated genes. If not specified, it takes the bottom 10% of the |
upper |
numeric The cutoff for up-regulated genes. If not specified, it takes the top 10% of the dataset |
useFDR |
logical Whether to filter by adjusted p-value |
This function takes in a BPNList object and returns a BPNList object with the enrichr slot updated with process EnrichR Results.
An object of class BPNList with its enrichr slot populated with the results
TRUETRUE
This function takes a BPNList object and performs a Geneset Enrichment Analysis and returns a BPNList object with the results of the GSEA
do_gsea_pod( bpn, species = "hsapiens", gmtfile = NULL, lower = NULL, upper = NULL, alpha = 0.05, minSize = 15, maxSize = 500, rankWithSignificance = FALSE, useFDR = TRUE )do_gsea_pod( bpn, species = "hsapiens", gmtfile = NULL, lower = NULL, upper = NULL, alpha = 0.05, minSize = 15, maxSize = 500, rankWithSignificance = FALSE, useFDR = TRUE )
bpn |
BPNList An object of class BPNList created from prepare_data |
species |
character One of the species for which we provide current GMT pathways. Currently the valid species are hsapiens, mmusculus and rnorvegicus. Cannot be specified along with gmtfile |
gmtfile |
character A full path to a GMT File you would like to use. Cannot be specified along with species |
lower |
numeric The cutoff for down-regulated genes. If not specified, it takes the bottom 10% of the dataset |
upper |
numeric The cutoff for up-regulated genes. If not specified, it takes the top 10% of the dataset |
alpha |
numeric The Alpha value for statistical significance. Defaults to 0.05. |
minSize |
numeric The minimum number of genes that should be in a pathway for it to be included in the analysis |
maxSize |
numeric The maximum number of genes that should be in a pathway for it to be included in the analysis |
rankWithSignificance |
logical Whether to rank genes using p-values |
useFDR |
logical Whether to filter by adjusted p-value |
This function takes a BPNList object and performs a Geneset Enrichment Analysis and returns a BPNList object with the results of the GSEA
An object of class BPNList with its gsea slot populated with the results
TRUETRUE
This method takes in a bpn object and performs a leading edge analysis to identify the genes that are driving the majority of pathways.
do_leading_pod(bpn)do_leading_pod(bpn)
bpn |
An object of class BPNList. Must have the gsea analysis completed beforehand. |
An object of class BPNList with its leading slot populated with the results
TRUETRUE
Construct an EnrichRResult object
EnrichRResult( up_results, down_results, upreg, downreg, alpha, upper, lower, dbs, useFDR )EnrichRResult( up_results, down_results, upreg, downreg, alpha, upper, lower, dbs, useFDR )
up_results |
tbl_df A tibble of enrichment results from the upregulated genes |
down_results |
tbl_df A tibble of enrichment results from the upregulated genes |
upreg |
tbl_df A tibble of up-regulated genes |
downreg |
tbl_df A tibble of down-regulated genes |
alpha |
numeric Alpha level of significance |
upper |
numeric Upper threshold for up-regulated genes |
lower |
numeric Lower threshold for down-regulated genes |
dbs |
character a vector of the databases used for the enrichment analysis |
useFDR |
logical Whether to filter by adjusted p-value |
an object of class EnrichRResult
TRUETRUE
This class stores the input parameters and results of the Gene Set Enrichment Analysis.
an object of class EnrichRResult
alphanumeric. The Alpha threshold for significance
threshold_upnumeric. The logfc threshold for up-regulated genes
threshold_downnumeric. The logfc threshold for down-regulated genes
upregulated_genestbl_df. The up-regulated genes from the input DEG tibble
downregulated_genestbl_df. The down-regulated genes from the input DEG tibble
dbs_usedcharacter. A vector of the databases used from enrichR
up_enrichrtbl_df. Enriched pathways in up-regulated genes
down_enrichrtbl_df. Enriched pathways in down-regulated genes
sig_up_enrichrtbl_df. Significant enriched pathways in up-regulated genes
sig_down_enrichrtbl_df. Significant enriched pathways in down-regulated genes
num_upregnumeric. Number of up-regulated genes
num_downregnumeric. Number of down-regulated genes
num_up_enrichrnumeric. Number of enriched pathways in up-regulated genes
num_down_enrichrnumeric. Number of enriched pathways in down-regulated genes
num_sig_up_enrichrnumeric. Number of significant enriched pathways in up-regulated genes
num_sig_down_enrichrnumeric. Number of significant enriched pathways in down-regulated genes
emptylogical. A simple check for whether or not the object is empty
TRUETRUE
Perform Revigo enrichment analysis
get_revigo_output(input_data)get_revigo_output(input_data)
input_data |
A dataframe containing GO IDs and associated p-values |
A dataframe containing the Revigo Enrichment analysis
TRUETRUE
Construct a GSEAResult Object
GSEAResult(results, pathways, lower, upper, alpha, upreg, downreg, useFDR)GSEAResult(results, pathways, lower, upper, alpha, upreg, downreg, useFDR)
results |
tbl_df A tibble with the results from fgsea |
pathways |
list A list of vectors with gene sets |
lower |
numeric Lower threshold for down-regulated genes |
upper |
numeric Upper threshold for up-regulated genes |
alpha |
numeric Alpha level of significance |
upreg |
tbl_df A tibble of up-regulated genes |
downreg |
tbl_df A tibble of down-regulated genes |
useFDR |
logical Whether to filter by adjusted p-value |
an object of class GSEAResult
TRUETRUE
This class stores the input parameters and results of the Gene Set Enrichment Analysis.
an object of class GSEAResult
alphanumeric. The Alpha threshold for significance
threshold_upnumeric. The logfc threshold for up-regulated genes
threshold_downnumeric. The logfc threshold for down-regulated genes
upregulated_genestbl_df. The up-regulated genes from the input DEG tibble
pathwaystbl_df. The pathways we used, either built-in or user-supplied
downregulated_genestbl_df. The down-regulated genes from the input DEG tibble
pos_enrichedtbl_df. The positively enriched pathways
neg_enrichedtbl_df. The negatively enriched pathways
sig_pos_enrichedtbl_df. Significant positively enriched pathways
sig_neg_enrichedtbl_df. Significant positively enriched pathways
num_upregnumeric. Number of up-regulated genes
num_downregnumeric. Number of down-regulated genes
num_testednumeric. Number of pathways tested
num_pos_enrichednumeric. Number of positively enriched pathways
num_neg_enrichednumeric. Number of negatively enriched pathways
num_sig_pos_enrichednumeric. Number of significant positively enriched pathways
num_sig_neg_enrichednumeric. Number of significant negatively enriched pathways
emptylogical. A simple check for whether or not the object is empty
TRUETRUE
The processed form of the October 2020 Pathway annotation containing every pathway annotated with the associated genes in humans. This uses the Symbol annotation from BaderLab.
hsapienshsapiens
A list
This class stores the result of the results from iLINCS
an object of class iLINCSResult
threshold_upnumeric. LFC threshold for up-regulated genes
threshold_downnumeric. LFC threshold for down-regulated genes
threshold_pvalnumeric. P Value threshold for genes.
threshold_similaritynumeric. Similarity threshold
l1000_subsettbl_df. Subset of L1000 genes in the dataset
upregulated_genestbl_df. L1000 genes up-regulatedd in dataset
downregulated_genestbl_df. L1000 genes down-regulated in dataset
ilincs_query_signaturetbl_df. Complete iLINCS Query signature
all_perturbagenstbl_df. Complete list returned from iLINCS of perturbagens
filtered_perturbagenstbl_df. Filtered list of perturbagens by the similarity threshold
num_genes_l1000numeric. Number of L1000 genes in dataset
num_genes_upregulatednumeric. Number of up-regulated L1000 genes in dataset
num_genes_downregulatednumeric. Number of down-regulated L1000 genes in dataset
num_all_perturbagensnumeric. Number of all perturbagens returned by iLINCS
num_filtered_perturbagensnumeric. Number of filtered perturbagens returned by iLINCS
emptylogical. A simple check for whether or not the object is empty
TRUETRUE
IntegratedResult-class: Class containing Integrated results
and object of class IntegratedResults
placeholdernumeric.
emptylogical. A simple check for whether or not the object is empty
TRUETRUE
Extract Leading Edge Genes from GSEA Results
leading_edge(gsea, direction)leading_edge(gsea, direction)
gsea |
an object of class GSEAResult |
direction |
one of "up" or "down" |
A tibble with the leading edge genes and associated pathways
TRUETRUE
Construct an LEResult object
LEResult(leading_up, leading_down)LEResult(leading_up, leading_down)
leading_up |
tbl_df. A dataframe with the results of all the leading edge genes from upregulated genes |
leading_down |
tbl_df. A dataframe with the results of all the leading edge genes from downregulated genes |
An object of class LEResult
TRUETRUE
LEResult-class: Class containing Leading Edge Analysis results
an object of class LEResult
leading_uptbl_df. A tibble with the results of LE analysis for the upregulated pathways
leading_downtbl_df. A tibble with the results of LE analysis for the downregulated pathways
count_leading_uptbl_df. A tibble with the counts of LE genes for the upregulated pathways
count_leading_downtbl_df. A tibble with the counts of LE genes for the downregulated pathways
num_leading_upnumeric. Number of LE genes for the upregulated pathways
num_leading_downnumeric. Number of LE genes for the downregulated pathways
emptylogical. A simple check for whether or not the object is empty
TRUETRUE
Load Pathways data
load_pathways(species)load_pathways(species)
species |
The species. Can be hsapiens, mmusculus or rnorvegicus |
The loaded pathways
importFrom utils data
TRUETRUE
The processed form of the October 2020 Pathway annotation containing every pathway annotated with the associated genes in mice. This uses the Symbol annotation from BaderLab.
mmusculusmmusculus
A list
This function takes vectors of gene names, log Fold-change values and optionally p-values and formats them into a tibble for downstream analysis.
prepare_data(genes, logfc, pvalues = NULL)prepare_data(genes, logfc, pvalues = NULL)
genes |
a character vector of gene names |
logfc |
a numeric vector of log fold-change values |
pvalues |
(optional) a numeric vector of p-values |
The function returns an object of class BPNList that will update as the analysis proceeds
An object of class BPNList with the following slot set:
input
TRUETRUE
RevigoResult-class: Class containing results from Revigo
and object of class RevigoResult
placeholdernumeric.
emptylogical. A simple check for whether or not the object is empty
TRUETRUE
The processed form of the October 2020 Pathway annotation containing every pathway annotated with the associated genes in rats. This uses the Symbol annotation from BaderLab.
rnorvegicusrnorvegicus
A list